@@ -33,7 +33,6 @@ try:
     if ("inkBoard" in __package__   ##For internal imports
         or "inkBoard" in getattr(__main__,"__file__","pssm") or "inkBoard" in entry_point   ##General usage
         or (hasattr(__main__,"debugpy") and __main__.cli.options.target == "inkBoard")): ##Debugging (in VScode using debugpy at least)
-        #or "inkBoard" in sys.modules ##Leaving this out for now as it would yield True for any point inkBoard is imported in.
         INKBOARD = True
 except:
     pass
@@ -75,6 +74,17 @@ class FEATURES:
     FEATURE_PRESS_RELEASE = "FEATURE_PRESS_RELEASE"
     "Feature to indicate the device is interactive and can report the coordinates of a press and the coordinates of a release"
 
+    @classmethod
+    def get_feature_string(cls, feature: str):
+        if hasattr(cls, feature):
+            return getattr(cls, feature)
+        
+        if not feature.startswith("FEATURE_"):
+            feature_str = "FEATURE_" + feature.upper()
+            return cls.get_feature_string(feature_str)
+        
+        raise AttributeError(f"Feature {feature} is not a valid value or shorthand")
+
 FEATURE_ATTRIBUTES = {
     FEATURES.FEATURE_BACKLIGHT: "backlight",
     FEATURES.FEATURE_BATTERY: "battery",
