@@ -3,11 +3,10 @@ Base device module for pssm devices. The `windowed` package is an out of the box
 """
 
 import asyncio
-from typing import TYPE_CHECKING, TypedDict, Literal, Optional, Union, Any
+from typing import TYPE_CHECKING, TypedDict, Literal, Optional, Union
 import logging
 from PIL import Image
 from abc import ABC, abstractmethod
-from dataclasses import dataclass, field, make_dataclass
 from contextlib import suppress
 
 from .const import *
@@ -30,7 +29,6 @@ if TYPE_CHECKING:
     from ..pssm_types import ColorType
 
 
-
 NetworkDict = TypedDict("NetworkDict",
                         {"connected": bool, "wifiOn":bool, "signal": str, "MAC": Optional[str], "SSID": Optional[str]})
 
@@ -260,13 +258,11 @@ class PSSMdevice(ABC):
         ----------
         feature: str
             The  feature to check. Use the constants from `FEATURES` to check, although some safeguarding is in place to convert passed values to valid feature strings.
-        """
-        if not feature.startswith("FEATURE_"):
-            feature_str = f"FEATURE_{feature}".upper()
-        else:
-            feature_str = feature
+        """        
+        with suppress(AttributeError):
+            feature = FEATURES.get_feature_string(feature)
 
-        return bool(getattr(self._features,feature_str,False))
+        return bool(getattr(self._features,feature,False))
     
     @abstractmethod
     async def async_pol_features(self):
@@ -302,7 +298,6 @@ class PSSMdevice(ABC):
         """
         ##This function is a leftover from the pure Eink version. Will be deprecated
         _LOGGER.debug("This base device function is deprecated")
-        # raise DeprecationWarning("This base device function is deprecated")
         pass
 
     def do_screen_clear(self):
@@ -515,7 +510,6 @@ class Backlight(ABC):
     @property
     def default_time_on(self) -> Union[float,int,str]:
         "Default  time to turn the backlight on for when calling the temporary backlight function. Controlled by parent screen"
-        # return self._device.parentPSSMScreen.backlight_time_on
         return self.__default_time_on
     
     @default_time_on.setter
