@@ -34,8 +34,9 @@ if tk._default_root:
 else:
     root = tk.Tk()
 
-canvas = tk.Canvas(root, background="gray",highlightthickness=0, name=CANVASNAME)
-canvas.pack(fill="both", expand=1)
+if CANVASNAME not in root.children:
+    canvas = tk.Canvas(root, background="gray",highlightthickness=0, name=CANVASNAME)
+    canvas.pack(fill="both", expand=1)
 
 def get_windows_network() -> NetworkDict:
     "Gets info on the currently connected network on windows machines"
@@ -376,7 +377,7 @@ class Device(PSSMdevice):
 
     def canvas_event(self,event : tk.Event):
         "Gets events from tkinter and passes them to PSSM."
-        logger.trace(f"Got event {event} from tkinter, passing to PSSM")
+        logger.verbose(f"Got event {event} from tkinter, passing to PSSM")
         if event.type == tk.EventType.ButtonPress:
             touch_type = const.TOUCH_PRESS
         elif event.type == tk.EventType.ButtonRelease:
@@ -508,7 +509,10 @@ class Device(PSSMdevice):
         self.parentPSSMScreen.quit()
 
     def _quit(self):
-        self._call_in_main_thread(self._quit_in_mainthread)
+        try:
+            self._call_in_main_thread(self._quit_in_mainthread)
+        except tk.TclError:
+            return
 
     def _quit_in_mainthread(self):
         for idx in self.canvas.find_all():
@@ -561,7 +565,6 @@ class Network(BaseNetwork):
 
     def __get_ip(self) -> str:
         """Gets the devices IP adress. Returns None if none found and sets the connected attribute appropriately"""
-        # return
         if not self.connected:
             logger.warning("Not connected to a network, setting IP to None")
             self._IP = None
@@ -625,7 +628,7 @@ class Backlight(BaseBacklight):
             return
         
         alpha = int(self.max_alpha - self.max_alpha*(level/100))
-        logger.trace(f"Backlight brightness to {level}%; Alpha channel is {alpha}")
+        logger.verbose(f"Backlight brightness to {level}%; Alpha channel is {alpha}")
         blImg = self.backlightImage
         blImg.putalpha(alpha) 
         self.blTk = ImageTk.PhotoImage(blImg)
@@ -688,7 +691,7 @@ class Backlight(BaseBacklight):
     async def turn_on_async(self, brightness : int = None, transition: float = None):
         """Async function to provide support for transitions at turn on. Does NOT perform sanity checks"""
 
-        logger.trace(f"Async turning on in {transition} seconds")
+        logger.verbose(f"Async turning on in {transition} seconds")
         
         if brightness == None:
             brightness = self.defaultBrightness
